#ifndef NT2_INCLUDE_CONSTANTS_EXPNIBIG_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_EXPNIBIG_HPP_INCLUDED

#include <nt2/exponential/include/constants/expnibig.hpp>

#endif
